<?php
/**
 * Clase TipoColaboradorRolBL
 *
 * @package    
 * @subpackage 
 * @author     TipoColaboradorRolBL
 * @version    SVN: $Id: TipoColaboradorRolBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class TipoColaboradorRolBL{
    
  /**
  * 
  *
  * @param $o_TipoColaboradorRolBean, objeto de tipo TipoColaboradorRol 
  * @return Boolean
  */
  public function busquedaTipoColaboradorRol(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
    
    $o_TipoColaboradorRolDP = new TipoColaboradorRolDP($o_TipoColaboradorRolBean);
    if($o_TipoColaboradorRolBean->getIdTipoColaborador()){
      return $o_TipoColaboradorRolDP->selectByPk();
    }else{
      return $o_TipoColaboradorRolDP->select();
    }
    
  }
  
  public function insertarTipoColaboradorRol(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
    
    $o_TipoColaboradorRolCT = new TipoColaboradorRolCT();
    return $o_TipoColaboradorRolCT->guardar($o_TipoColaboradorRolBean);
    
  }
  	public function modificarTipoColaboradorRol(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
	  
    $o_TipoColaboradorRolCT = new TipoColaboradorRolCT();
    return $o_TipoColaboradorRolCT->modificar($o_TipoColaboradorRolBean);
	
	}
  /**
	* Función que retorna un objeto TipoColaboradorRol o una lista de Objetos de TipoColaboradorRol,
	* dependiendo del parametro que se le envia si este contiene o no el Id de TipoColaboradorRol
	*
	* @param $o_TipoColaboradorRolBean, es un objeto de tipo TipoColaboradorRol
	* @return Object
	*/
	public function modificarEstadoTipoColaboradorRol(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
	  $o_TipoColaboradorRolCT = new TipoColaboradorRolCT();
    return $o_TipoColaboradorRolCT->modificar($o_TipoColaboradorRolBean);
	
	}
	
	public function getTipoInvetigacion(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
    
    $o_TipoColaboradorRolCT = new TipoColaboradorRolCT();
    return $o_TipoColaboradorRolCT->seleccionar($o_TipoColaboradorRolBean);
    
  }
  
  public function eliminarTipoColaboradorRol(TipoColaboradorRolBean $o_TipoColaboradorRolBean){
     $o_TipoColaboradorRolCT = new TipoColaboradorRolCT();
    return $o_TipoColaboradorRolCT->eliminar($o_TipoColaboradorRolBean);
  }
  
}



