<?php

class TipoColaboradorRolSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
     $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertTipoColaboradorRol(){
    
    $o_TipoColaboradorRolBL = new TipoColaboradorRolBL();
    return $o_TipoColaboradorRolBL->insertarTipoColaboradorRol($this->getObjParamBean());
    
  }
   
  public function eliminarTipoColaboradorRol(){
    
    $o_TipoColaboradorRolBL = new TipoColaboradorRolBL();
    return $o_TipoColaboradorRolBL->eliminarTipoColaboradorRol($this->getObjParamBean());
    
  }
  
  public function actualizarTipoColaboradorRol(){
    
    $o_TipoColaboradorRolBL = new TipoColaboradorRolBL();
    return $o_TipoColaboradorRolBL->modificarTipoColaboradorRol($this->getObjParamBean());
    
  }
  
  public function getTipoTipoColaboradorRol(){
  
    $o_TipoTipoColaboradorRolBL = new TipoTipoColaboradorRolBL();
    return $o_TipoTipoColaboradorRolBL->busquedaTipoTipoColaboradorRol($this->getObjParamBean());
  
  }
  
  public function getTipoColaboradorRol(){
  
    $o_TipoColaboradorRolBL = new TipoColaboradorRolBL();
    return $o_TipoColaboradorRolBL->getTipoColaboradorRol($this->getObjParamBean());
  
  }
  
  public function getFacultad(){
    
    $o_FacultadBL = new FacultadBL();
    return $o_FacultadBL->getFacultad($this->getObjParamBean());
  }
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }
  
 /* public function getTipoColaboradorRol(){
    
    $o_TipoColaboradorRolBL = new TipoColaboradorRolBL();
    return $o_TipoColaboradorRolBL->busquedaTipoColaboradorRol(new TipoColaboradorRolBean());
    
  }*/

}